==> jc-1.4.0.tar.gz: javax/naming/ldap/InitialLdapContext.h <==
// public class javax.naming.ldap.InitialLdapContext

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class af75328c6fc82556 javax_naming_InitialContext
// @dep_class c50a7797eed73bb5 javax_naming_directory_InitialDirContext
// @dep_class 1064fb142eba001a javax_naming_ldap_InitialLdapContext

// header file dependencies
// @dep_header javax_naming_directory_InitialDirContext

#include "javax/naming/directory/InitialDirContext.h"

#ifndef _JC_javax_naming_ldap_InitialLdapContext_H_
#define _JC_javax_naming_ldap_InitialLdapContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_ldap_ExtendedRequest$object;
struct _jc_javax_naming_ldap_ExtendedResponse$object;
struct _jc_javax_naming_ldap_LdapContext$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_InitialLdapContext$sub_refs	_jc_javax_naming_ldap_InitialLdapContext$sub_refs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs	_jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$refs	_jc_javax_naming_ldap_InitialLdapContext$refs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$nonrefs	_jc_javax_naming_ldap_InitialLdapContext$nonrefs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$object	_jc_javax_naming_ldap_InitialLdapContext$object;

typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vmethods	_jc_javax_naming_ldap_InitialLdapContext$vmethods;
typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vtable	_jc_javax_naming_ldap_InitialLdapContext$vtable;
typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vtype	_jc_javax_naming_ldap_InitialLdapContext$vtype;

// Constructors
extern void _jc_javax_naming_ldap_InitialLdapContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
extern void _jc_javax_naming_ldap_InitialLdapContext$method$_init$c51bde97516024b9(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *);

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$extendedOperation$0fa24e9a349ff68b(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object *);
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getConnectControls$a7fc89d3dc6233f7(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$getDefaultInitLdapCtx$e9451d994a24a374(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getRequestControls$96c52982c34c1c55(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getResponseControls$f65eacbab8fab985(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$newInstance$fe2126af9f9ef98f(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);
extern void _jc_javax_naming_ldap_InitialLdapContext$method$reconnect$9dbe6e01751c0990(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);
extern void _jc_javax_naming_ldap_InitialLdapContext$method$setRequestControls$d29519393cc6766d(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$extendedOperation$0fa24e9a349ff68b;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getConnectControls$a7fc89d3dc6233f7;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getDefaultInitLdapCtx$e9451d994a24a374;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getRequestControls$96c52982c34c1c55;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getResponseControls$f65eacbab8fab985;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$newInstance$fe2126af9f9ef98f;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$reconnect$9dbe6e01751c0990;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$setRequestControls$d29519393cc6766d;

// Virtual methods structure
struct _jc_javax_naming_ldap_InitialLdapContext$vmethods {
	struct _jc_object	*(*extendedOperation$0fa24e9a349ff68b)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object *);
	_jc_object_array	*(*getConnectControls$a7fc89d3dc6233f7)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
	struct _jc_object	*(*getDefaultInitLdapCtx$e9451d994a24a374)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
	_jc_object_array	*(*getRequestControls$96c52982c34c1c55)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
	_jc_object_array	*(*getResponseControls$f65eacbab8fab985)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *);
	struct _jc_object	*(*newInstance$fe2126af9f9ef98f)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);
	void	(*reconnect$9dbe6e01751c0990)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);
	void	(*setRequestControls$d29519393cc6766d)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_javax_naming_ldap_InitialLdapContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_InitialContext$vmethods	javax_naming_InitialContext;
	_jc_javax_naming_directory_InitialDirContext$vmethods	javax_naming_directory_InitialDirContext;
	_jc_javax_naming_ldap_InitialLdapContext$vmethods	javax_naming_ldap_InitialLdapContext;
};

// Vtype
struct _jc_javax_naming_ldap_InitialLdapContext$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_InitialLdapContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_InitialLdapContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_InitialLdapContext$refs {
    _jc_javax_naming_ldap_InitialLdapContext$sub_refs	javax_naming_ldap_InitialLdapContext;
    _jc_javax_naming_directory_InitialDirContext$sub_refs	javax_naming_directory_InitialDirContext;
    _jc_javax_naming_InitialContext$sub_refs	javax_naming_InitialContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_InitialLdapContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_InitialContext$sub_nonrefs	javax_naming_InitialContext;
    _jc_javax_naming_directory_InitialDirContext$sub_nonrefs	javax_naming_directory_InitialDirContext;
    _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs	javax_naming_ldap_InitialLdapContext;
};

// Object instance structure
struct _jc_javax_naming_ldap_InitialLdapContext$object {
	_jc_javax_naming_ldap_InitialLdapContext$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_InitialLdapContext$vtype	*vtype;
	_jc_javax_naming_ldap_InitialLdapContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_InitialLdapContext$vtype _jc_javax_naming_ldap_InitialLdapContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_InitialLdapContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_InitialLdapContext$class_object;

#endif	/* _JC_javax_naming_ldap_InitialLdapContext_H_ */

==> jc-1.4.6.tar.gz: javax/naming/ldap/InitialLdapContext.h <==
// public class javax.naming.ldap.InitialLdapContext

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class af75328c6fc82556 javax_naming_InitialContext
// @dep_class c50a7797eed73bb5 javax_naming_directory_InitialDirContext
// @dep_class 1064fb142eba001a javax_naming_ldap_InitialLdapContext

// header file dependencies
// @dep_header javax_naming_directory_InitialDirContext

#include "javax/naming/directory/InitialDirContext.h"

#ifndef _JC_javax_naming_ldap_InitialLdapContext_H_
#define _JC_javax_naming_ldap_InitialLdapContext_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_Hashtable$object;
struct _jc_javax_naming_ldap_ExtendedRequest$object;
struct _jc_javax_naming_ldap_ExtendedResponse$object;
struct _jc_javax_naming_ldap_LdapContext$object;

// Typedefs
typedef struct _jc_javax_naming_ldap_InitialLdapContext$sub_refs	_jc_javax_naming_ldap_InitialLdapContext$sub_refs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs	_jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$refs	_jc_javax_naming_ldap_InitialLdapContext$refs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$nonrefs	_jc_javax_naming_ldap_InitialLdapContext$nonrefs;
typedef struct _jc_javax_naming_ldap_InitialLdapContext$object	_jc_javax_naming_ldap_InitialLdapContext$object;

typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vmethods	_jc_javax_naming_ldap_InitialLdapContext$vmethods;
typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vtable	_jc_javax_naming_ldap_InitialLdapContext$vtable;
typedef const struct _jc_javax_naming_ldap_InitialLdapContext$vtype	_jc_javax_naming_ldap_InitialLdapContext$vtype;

// Constructors
extern void _jc_javax_naming_ldap_InitialLdapContext$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ldap_InitialLdapContext$method$_init$c51bde97516024b9(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_java_util_Hashtable$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$extendedOperation$0fa24e9a349ff68b(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getConnectControls$a7fc89d3dc6233f7(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$getDefaultInitLdapCtx$e9451d994a24a374(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getRequestControls$96c52982c34c1c55(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_naming_ldap_InitialLdapContext$method$getResponseControls$f65eacbab8fab985(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_javax_naming_ldap_InitialLdapContext$method$newInstance$fe2126af9f9ef98f(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ldap_InitialLdapContext$method$reconnect$9dbe6e01751c0990(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_javax_naming_ldap_InitialLdapContext$method$setRequestControls$d29519393cc6766d(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$extendedOperation$0fa24e9a349ff68b;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getConnectControls$a7fc89d3dc6233f7;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getDefaultInitLdapCtx$e9451d994a24a374;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getRequestControls$96c52982c34c1c55;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$getResponseControls$f65eacbab8fab985;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$newInstance$fe2126af9f9ef98f;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$reconnect$9dbe6e01751c0990;
extern _jc_method _jc_javax_naming_ldap_InitialLdapContext$method_info$setRequestControls$d29519393cc6766d;

// Virtual methods structure
struct _jc_javax_naming_ldap_InitialLdapContext$vmethods {
	struct _jc_object	*(*extendedOperation$0fa24e9a349ff68b)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getConnectControls$a7fc89d3dc6233f7)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getDefaultInitLdapCtx$e9451d994a24a374)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getRequestControls$96c52982c34c1c55)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*getResponseControls$f65eacbab8fab985)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*newInstance$fe2126af9f9ef98f)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	void	(*reconnect$9dbe6e01751c0990)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
	void	(*setRequestControls$d29519393cc6766d)(_jc_env *, struct _jc_javax_naming_ldap_InitialLdapContext$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_naming_ldap_InitialLdapContext$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_naming_InitialContext$vmethods	javax_naming_InitialContext;
	_jc_javax_naming_directory_InitialDirContext$vmethods	javax_naming_directory_InitialDirContext;
	_jc_javax_naming_ldap_InitialLdapContext$vmethods	javax_naming_ldap_InitialLdapContext;
};

// Vtype
struct _jc_javax_naming_ldap_InitialLdapContext$vtype {
	_jc_type			type;
	_jc_javax_naming_ldap_InitialLdapContext$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_naming_ldap_InitialLdapContext$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_naming_ldap_InitialLdapContext$refs {
    _jc_javax_naming_ldap_InitialLdapContext$sub_refs	javax_naming_ldap_InitialLdapContext;
    _jc_javax_naming_directory_InitialDirContext$sub_refs	javax_naming_directory_InitialDirContext;
    _jc_javax_naming_InitialContext$sub_refs	javax_naming_InitialContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_naming_ldap_InitialLdapContext$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_naming_InitialContext$sub_nonrefs	javax_naming_InitialContext;
    _jc_javax_naming_directory_InitialDirContext$sub_nonrefs	javax_naming_directory_InitialDirContext;
    _jc_javax_naming_ldap_InitialLdapContext$sub_nonrefs	javax_naming_ldap_InitialLdapContext;
};

// Object instance structure
struct _jc_javax_naming_ldap_InitialLdapContext$object {
	_jc_javax_naming_ldap_InitialLdapContext$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_naming_ldap_InitialLdapContext$vtype	*vtype;
	_jc_javax_naming_ldap_InitialLdapContext$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_naming_ldap_InitialLdapContext$vtype _jc_javax_naming_ldap_InitialLdapContext$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_naming_ldap_InitialLdapContext, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_naming_ldap_InitialLdapContext$class_object;

#endif	/* _JC_javax_naming_ldap_InitialLdapContext_H_ */
